"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importStar(require("react"));
const context_1 = tslib_1.__importDefault(require("./context"));
const QuizQuestions_1 = tslib_1.__importDefault(require("../QuizQuestions"));
const ResultContainer_1 = tslib_1.__importDefault(require("../ResultContainer/ResultContainer"));
const constants_1 = require("../../constants");
const Spinner_1 = tslib_1.__importDefault(require("../Spinner/Spinner"));
const useQuiz_1 = tslib_1.__importDefault(require("../../hooks/useQuiz"));
const SessionPromptModal_1 = tslib_1.__importDefault(require("../SessionPromptModal/SessionPromptModal"));
const utils_1 = require("../../utils");
function CioQuiz(props) {
    const { cioClient, state, events: { hydrateQuiz, hasSessionStorageState, resetSessionStorageState }, getAddToCartButtonProps, getCoverQuestionProps, getHydrateQuizButtonProps, getNextQuestionButtonProps, getOpenTextInputProps, getPreviousQuestionButtonProps, getQuizImageProps, getQuizResultButtonProps, getQuizResultLinkProps, getResetQuizButtonProps, getSelectInputProps, primaryColorStyles, } = (0, useQuiz_1.default)(props);
    const [showSessionPrompt, setShowSessionPrompt] = (0, react_1.useState)(false);
    const { resultsPageOptions, sessionStateOptions } = props;
    (0, react_1.useEffect)(() => {
        // Respect showSessionModal if defined, else default to true.
        if ((sessionStateOptions === null || sessionStateOptions === void 0 ? void 0 : sessionStateOptions.showSessionModal) !== undefined) {
            setShowSessionPrompt((sessionStateOptions === null || sessionStateOptions === void 0 ? void 0 : sessionStateOptions.showSessionModal) && hasSessionStorageState());
        }
        else {
            setShowSessionPrompt(hasSessionStorageState());
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, []);
    const contextValue = {
        cioClient,
        state,
        getAddToCartButtonProps,
        getCoverQuestionProps,
        getHydrateQuizButtonProps,
        getNextQuestionButtonProps,
        getOpenTextInputProps,
        getPreviousQuestionButtonProps,
        getQuizImageProps,
        getQuizResultButtonProps,
        getQuizResultLinkProps,
        getResetQuizButtonProps,
        getSelectInputProps,
        customClickItemCallback: !!(resultsPageOptions === null || resultsPageOptions === void 0 ? void 0 : resultsPageOptions.onQuizResultClick),
        primaryColorStyles,
    };
    if (state.quiz.requestState === constants_1.RequestStates.Loading) {
        return (react_1.default.createElement("div", { className: 'cio-quiz' },
            react_1.default.createElement(Spinner_1.default, null)));
    }
    if (state.quiz.requestState === constants_1.RequestStates.Success) {
        return (react_1.default.createElement("div", { className: 'cio-quiz' },
            react_1.default.createElement("style", null,
                ".cio-quiz ",
                (0, utils_1.convertPrimaryColorsToString)(primaryColorStyles)),
            react_1.default.createElement(SessionPromptModal_1.default, { resetStoredState: resetSessionStorageState, continueSession: hydrateQuiz, showSessionPrompt: showSessionPrompt, setShowSessionPrompt: setShowSessionPrompt }),
            react_1.default.createElement(context_1.default.Provider, { value: contextValue },
                state.quiz.results && react_1.default.createElement(ResultContainer_1.default, { options: resultsPageOptions }),
                state.quiz.currentQuestion && react_1.default.createElement(QuizQuestions_1.default, null))));
    }
    return null;
}
exports.default = CioQuiz;
