import React, { useContext } from 'react';
import QuestionTitle from '../QuestionTitle/QuestionTitle';
import QuestionDescription from '../QuestionDescription/QuestionDescription';
import QuizContext from '../CioQuiz/context';
import { renderImages } from '../../utils';
import ControlBar from '../ControlBar/ControlBar';
import { QuestionTypes } from '../CioQuiz/actions';
function SelectTypeQuestion() {
    const { state, getSelectInputProps } = useContext(QuizContext);
    let question;
    let hasImages = false;
    let instructions;
    if (state?.quiz.currentQuestion) {
        question = state.quiz.currentQuestion.next_question;
        hasImages = question.options.some((option) => option.images);
        instructions = question.type === QuestionTypes.MultipleSelect && 'Select one or more options';
    }
    if (question) {
        return (React.createElement("div", { className: 'cio-select-question-container', "data-question-key": question.key },
            React.createElement("div", { className: 'cio-select-question-text' },
                React.createElement(QuestionTitle, { title: question.title }),
                question?.description ? React.createElement(QuestionDescription, { description: question.description }) : ''),
            instructions && React.createElement("div", { className: 'cio-select-question-instructions' }, instructions),
            React.createElement("div", { className: `${!hasImages
                    ? 'cio-question-options-container-text-only'
                    : 'cio-question-options-container'}` }, question?.options?.map((option) => getSelectInputProps && (React.createElement("div", { ...getSelectInputProps(option) },
                option.images ? renderImages(option.images, 'cio-question-option-image') : '',
                React.createElement("div", { className: 'cio-question-option-value' }, option?.value))))),
            React.createElement(ControlBar, { ctaButtonText: question?.cta_text || 'Continue' })));
    }
    return null;
}
export default SelectTypeQuestion;
