import { useCallback, useEffect, useReducer } from 'react';
import quizLocalReducer, { initialState } from '../../components/CioQuiz/quizLocalReducer';
import { quizSessionStateKey } from '../../constants';
import { getStateFromSessionStorage, logger } from '../../utils';
const useQuizLocalState = (sessionStateKey) => {
    const [quizLocalState, dispatch] = useReducer(quizLocalReducer, initialState);
    const quizStateKey = sessionStateKey || quizSessionStateKey;
    useEffect(() => {
        // don't save state if initial state
        if (quizLocalState?.answers?.length) {
            window?.sessionStorage?.setItem(quizStateKey, JSON.stringify(quizLocalState));
        }
    }, [quizLocalState, quizStateKey]);
    const hasQuizStoredState = () => getStateFromSessionStorage(quizStateKey) !== null;
    const dispatchLocalState = useCallback((action) => {
        logger(action);
        dispatch(action);
    }, []);
    return {
        quizLocalState,
        hasQuizStoredState,
        dispatchLocalState,
        quizStateKey,
    };
};
export default useQuizLocalState;
